# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BinTObjDrivers module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_bintobjdrivers.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BinTObjDrivers
else:
    import _BinTObjDrivers

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BinTObjDrivers.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BinTObjDrivers.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BinTObjDrivers.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BinTObjDrivers.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BinTObjDrivers.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BinTObjDrivers.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinTObjDrivers.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BinTObjDrivers.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BinTObjDrivers.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BinTObjDrivers.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BinTObjDrivers:
_BinTObjDrivers.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BinTObjDrivers.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BinMDF
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TDF
import OCC.Core.BinObjMgt
import OCC.Core.Storage
import OCC.Core.TDocStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.BinLDrivers

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_BinTObjDrivers_DocumentRetrievalDriver_Create() -> "opencascade::handle< BinTObjDrivers_DocumentRetrievalDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentRetrievalDriver_Create()

def Handle_BinTObjDrivers_DocumentRetrievalDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_DocumentRetrievalDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentRetrievalDriver_DownCast(t)

def Handle_BinTObjDrivers_DocumentRetrievalDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_DocumentRetrievalDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentRetrievalDriver_IsNull(t)

def Handle_BinTObjDrivers_DocumentStorageDriver_Create() -> "opencascade::handle< BinTObjDrivers_DocumentStorageDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentStorageDriver_Create()

def Handle_BinTObjDrivers_DocumentStorageDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_DocumentStorageDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentStorageDriver_DownCast(t)

def Handle_BinTObjDrivers_DocumentStorageDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_DocumentStorageDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_DocumentStorageDriver_IsNull(t)

def Handle_BinTObjDrivers_IntSparseArrayDriver_Create() -> "opencascade::handle< BinTObjDrivers_IntSparseArrayDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_IntSparseArrayDriver_Create()

def Handle_BinTObjDrivers_IntSparseArrayDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_IntSparseArrayDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_IntSparseArrayDriver_DownCast(t)

def Handle_BinTObjDrivers_IntSparseArrayDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_IntSparseArrayDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_IntSparseArrayDriver_IsNull(t)

def Handle_BinTObjDrivers_ModelDriver_Create() -> "opencascade::handle< BinTObjDrivers_ModelDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ModelDriver_Create()

def Handle_BinTObjDrivers_ModelDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_ModelDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ModelDriver_DownCast(t)

def Handle_BinTObjDrivers_ModelDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_ModelDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ModelDriver_IsNull(t)

def Handle_BinTObjDrivers_ObjectDriver_Create() -> "opencascade::handle< BinTObjDrivers_ObjectDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ObjectDriver_Create()

def Handle_BinTObjDrivers_ObjectDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_ObjectDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ObjectDriver_DownCast(t)

def Handle_BinTObjDrivers_ObjectDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_ObjectDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ObjectDriver_IsNull(t)

def Handle_BinTObjDrivers_ReferenceDriver_Create() -> "opencascade::handle< BinTObjDrivers_ReferenceDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ReferenceDriver_Create()

def Handle_BinTObjDrivers_ReferenceDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_ReferenceDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ReferenceDriver_DownCast(t)

def Handle_BinTObjDrivers_ReferenceDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_ReferenceDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_ReferenceDriver_IsNull(t)

def Handle_BinTObjDrivers_XYZDriver_Create() -> "opencascade::handle< BinTObjDrivers_XYZDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_XYZDriver_Create()

def Handle_BinTObjDrivers_XYZDriver_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< BinTObjDrivers_XYZDriver >":
    return _BinTObjDrivers.Handle_BinTObjDrivers_XYZDriver_DownCast(t)

def Handle_BinTObjDrivers_XYZDriver_IsNull(t: "opencascade::handle< BinTObjDrivers_XYZDriver > const &") -> "bool":
    return _BinTObjDrivers.Handle_BinTObjDrivers_XYZDriver_IsNull(t)
class bintobjdrivers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AddDrivers(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        aDriverTable: BinMDF_ADriverTable
        aMsgDrv: Message_Messenger

        Returns
        -------
        None

        """
        return _BinTObjDrivers.bintobjdrivers_AddDrivers(*args)

    @staticmethod
    def DefineFormat(*args) -> "void":
        r"""
        Defines format 'tobjbin' and registers its read and write drivers in the specified application.

        Parameters
        ----------
        theApp: TDocStd_Application

        Returns
        -------
        None

        """
        return _BinTObjDrivers.bintobjdrivers_DefineFormat(*args)

    @staticmethod
    def Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
        r"""
        No available documentation.

        Parameters
        ----------
        aGUID: Standard_GUID

        Returns
        -------
        opencascade::handle<Standard_Transient>

        """
        return _BinTObjDrivers.bintobjdrivers_Factory(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _BinTObjDrivers.bintobjdrivers_swiginit(self, _BinTObjDrivers.new_bintobjdrivers())
    __swig_destroy__ = _BinTObjDrivers.delete_bintobjdrivers

# Register bintobjdrivers in _BinTObjDrivers:
_BinTObjDrivers.bintobjdrivers_swigregister(bintobjdrivers)

def bintobjdrivers_AddDrivers(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    aDriverTable: BinMDF_ADriverTable
    aMsgDrv: Message_Messenger

    Returns
    -------
    None

    """
    return _BinTObjDrivers.bintobjdrivers_AddDrivers(*args)

def bintobjdrivers_DefineFormat(*args) -> "void":
    r"""
    Defines format 'tobjbin' and registers its read and write drivers in the specified application.

    Parameters
    ----------
    theApp: TDocStd_Application

    Returns
    -------
    None

    """
    return _BinTObjDrivers.bintobjdrivers_DefineFormat(*args)

def bintobjdrivers_Factory(*args) -> "opencascade::handle< Standard_Transient > const &":
    r"""
    No available documentation.

    Parameters
    ----------
    aGUID: Standard_GUID

    Returns
    -------
    opencascade::handle<Standard_Transient>

    """
    return _BinTObjDrivers.bintobjdrivers_Factory(*args)

class BinTObjDrivers_DocumentRetrievalDriver(OCC.Core.BinLDrivers.BinLDrivers_DocumentRetrievalDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_DocumentRetrievalDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_DocumentRetrievalDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_DocumentRetrievalDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_DocumentRetrievalDriver

# Register BinTObjDrivers_DocumentRetrievalDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_DocumentRetrievalDriver_swigregister(BinTObjDrivers_DocumentRetrievalDriver)

class BinTObjDrivers_DocumentStorageDriver(OCC.Core.BinLDrivers.BinLDrivers_DocumentStorageDriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_DocumentStorageDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_DocumentStorageDriver(*args))


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_DocumentStorageDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_DocumentStorageDriver

# Register BinTObjDrivers_DocumentStorageDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_DocumentStorageDriver_swigregister(BinTObjDrivers_DocumentStorageDriver)

class BinTObjDrivers_IntSparseArrayDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_IntSparseArrayDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_IntSparseArrayDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: BinObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: BinObjMgt_Persistent
        theRelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_IntSparseArrayDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_IntSparseArrayDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_IntSparseArrayDriver

# Register BinTObjDrivers_IntSparseArrayDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_IntSparseArrayDriver_swigregister(BinTObjDrivers_IntSparseArrayDriver)

class BinTObjDrivers_ModelDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_ModelDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_ModelDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_ModelDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_ModelDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_ModelDriver

# Register BinTObjDrivers_ModelDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_ModelDriver_swigregister(BinTObjDrivers_ModelDriver)

class BinTObjDrivers_ObjectDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_ObjectDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_ObjectDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_ObjectDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_ObjectDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_ObjectDriver

# Register BinTObjDrivers_ObjectDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_ObjectDriver_swigregister(BinTObjDrivers_ObjectDriver)

class BinTObjDrivers_ReferenceDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_ReferenceDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_ReferenceDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Source: BinObjMgt_Persistent
        Target: TDF_Attribute
        RelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        Source: TDF_Attribute
        Target: BinObjMgt_Persistent
        RelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_ReferenceDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_ReferenceDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_ReferenceDriver

# Register BinTObjDrivers_ReferenceDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_ReferenceDriver_swigregister(BinTObjDrivers_ReferenceDriver)

class BinTObjDrivers_XYZDriver(OCC.Core.BinMDF.BinMDF_ADriver):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Parameters
        ----------
        theMessageDriver: Message_Messenger

        Returns
        -------
        None

        """
        _BinTObjDrivers.BinTObjDrivers_XYZDriver_swiginit(self, _BinTObjDrivers.new_BinTObjDrivers_XYZDriver(*args))

    def Paste(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        theSource: BinObjMgt_Persistent
        theTarget: TDF_Attribute
        theRelocTable: BinObjMgt_RRelocationTable

        Returns
        -------
        bool
        No available documentation.

        Parameters
        ----------
        theSource: TDF_Attribute
        theTarget: BinObjMgt_Persistent
        theRelocTable: BinObjMgt_SRelocationTable

        Returns
        -------
        None

        """
        return _BinTObjDrivers.BinTObjDrivers_XYZDriver_Paste(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_BinTObjDrivers_XYZDriver_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _BinTObjDrivers.delete_BinTObjDrivers_XYZDriver

# Register BinTObjDrivers_XYZDriver in _BinTObjDrivers:
_BinTObjDrivers.BinTObjDrivers_XYZDriver_swigregister(BinTObjDrivers_XYZDriver)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class elclib:
	@staticmethod
	def AdjustPeriodic(UFirst: float, ULast: float, Precision: float) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def CircleD1(U: float, Pos: gp_Ax2, Radius: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CircleD1(U: float, Pos: gp_Ax22d, Radius: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CircleD2(U: float, Pos: gp_Ax2, Radius: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CircleD2(U: float, Pos: gp_Ax22d, Radius: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CircleD3(U: float, Pos: gp_Ax2, Radius: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def CircleD3(U: float, Pos: gp_Ax22d, Radius: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def CircleDN(U: float, Pos: gp_Ax2, Radius: float, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def CircleDN(U: float, Pos: gp_Ax22d, Radius: float, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def CircleParameter(Pos: gp_Ax2, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def CircleParameter(Pos: gp_Ax22d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def CircleValue(U: float, Pos: gp_Ax2, Radius: float) -> gp_Pnt: ...
	@overload
	@staticmethod
	def CircleValue(U: float, Pos: gp_Ax22d, Radius: float) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def D1(U: float, L: gp_Lin, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, C: gp_Circ, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, E: gp_Elips, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, H: gp_Hypr, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, Prb: gp_Parab, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, L: gp_Lin2d, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, C: gp_Circ2d, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, E: gp_Elips2d, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, H: gp_Hypr2d, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D1(U: float, Prb: gp_Parab2d, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, C: gp_Circ, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, E: gp_Elips, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, H: gp_Hypr, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, Prb: gp_Parab, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, C: gp_Circ2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, E: gp_Elips2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, H: gp_Hypr2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D2(U: float, Prb: gp_Parab2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, C: gp_Circ, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, E: gp_Elips, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, H: gp_Hypr, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, C: gp_Circ2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, E: gp_Elips2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def D3(U: float, H: gp_Hypr2d, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def DN(U: float, L: gp_Lin, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, C: gp_Circ, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, E: gp_Elips, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, H: gp_Hypr, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, Prb: gp_Parab, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def DN(U: float, L: gp_Lin2d, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def DN(U: float, C: gp_Circ2d, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def DN(U: float, E: gp_Elips2d, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def DN(U: float, H: gp_Hypr2d, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def DN(U: float, Prb: gp_Parab2d, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def EllipseD1(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def EllipseD1(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def EllipseD2(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def EllipseD2(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def EllipseD3(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def EllipseD3(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def EllipseDN(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def EllipseDN(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def EllipseParameter(Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def EllipseParameter(Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def EllipseValue(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float) -> gp_Pnt: ...
	@overload
	@staticmethod
	def EllipseValue(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def HyperbolaD1(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def HyperbolaD1(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def HyperbolaD2(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def HyperbolaD2(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def HyperbolaD3(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def HyperbolaD3(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d, V3: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def HyperbolaDN(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def HyperbolaDN(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def HyperbolaParameter(Pos: gp_Ax2, MajorRadius: float, MinorRadius: float, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def HyperbolaParameter(Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def HyperbolaValue(U: float, Pos: gp_Ax2, MajorRadius: float, MinorRadius: float) -> gp_Pnt: ...
	@overload
	@staticmethod
	def HyperbolaValue(U: float, Pos: gp_Ax22d, MajorRadius: float, MinorRadius: float) -> gp_Pnt2d: ...
	@staticmethod
	def InPeriod(U: float, UFirst: float, ULast: float) -> float: ...
	@overload
	@staticmethod
	def LineD1(U: float, Pos: gp_Ax1, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def LineD1(U: float, Pos: gp_Ax2d, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def LineDN(U: float, Pos: gp_Ax1, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def LineDN(U: float, Pos: gp_Ax2d, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def LineParameter(Pos: gp_Ax1, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def LineParameter(Pos: gp_Ax2d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def LineValue(U: float, Pos: gp_Ax1) -> gp_Pnt: ...
	@overload
	@staticmethod
	def LineValue(U: float, Pos: gp_Ax2d) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def ParabolaD1(U: float, Pos: gp_Ax2, Focal: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def ParabolaD1(U: float, Pos: gp_Ax22d, Focal: float, P: gp_Pnt2d, V1: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def ParabolaD2(U: float, Pos: gp_Ax2, Focal: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@overload
	@staticmethod
	def ParabolaD2(U: float, Pos: gp_Ax22d, Focal: float, P: gp_Pnt2d, V1: gp_Vec2d, V2: gp_Vec2d) -> None: ...
	@overload
	@staticmethod
	def ParabolaDN(U: float, Pos: gp_Ax2, Focal: float, N: int) -> gp_Vec: ...
	@overload
	@staticmethod
	def ParabolaDN(U: float, Pos: gp_Ax22d, Focal: float, N: int) -> gp_Vec2d: ...
	@overload
	@staticmethod
	def ParabolaParameter(Pos: gp_Ax2, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def ParabolaParameter(Pos: gp_Ax22d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def ParabolaValue(U: float, Pos: gp_Ax2, Focal: float) -> gp_Pnt: ...
	@overload
	@staticmethod
	def ParabolaValue(U: float, Pos: gp_Ax22d, Focal: float) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Parameter(L: gp_Lin, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def Parameter(L: gp_Lin2d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def Parameter(C: gp_Circ, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def Parameter(C: gp_Circ2d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def Parameter(E: gp_Elips, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def Parameter(E: gp_Elips2d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def Parameter(H: gp_Hypr, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def Parameter(H: gp_Hypr2d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def Parameter(Prb: gp_Parab, P: gp_Pnt) -> float: ...
	@overload
	@staticmethod
	def Parameter(Prb: gp_Parab2d, P: gp_Pnt2d) -> float: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, P: gp_Pnt2d) -> gp_Pnt: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, V: gp_Vec2d) -> gp_Vec: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, V: gp_Dir2d) -> gp_Dir: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, A: gp_Ax2d) -> gp_Ax1: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, A: gp_Ax22d) -> gp_Ax2: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, L: gp_Lin2d) -> gp_Lin: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, C: gp_Circ2d) -> gp_Circ: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, E: gp_Elips2d) -> gp_Elips: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, H: gp_Hypr2d) -> gp_Hypr: ...
	@overload
	@staticmethod
	def To3d(Pos: gp_Ax2, Prb: gp_Parab2d) -> gp_Parab: ...
	@overload
	@staticmethod
	def Value(U: float, L: gp_Lin) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, C: gp_Circ) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, E: gp_Elips) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, H: gp_Hypr) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, Prb: gp_Parab) -> gp_Pnt: ...
	@overload
	@staticmethod
	def Value(U: float, L: gp_Lin2d) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Value(U: float, C: gp_Circ2d) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Value(U: float, E: gp_Elips2d) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Value(U: float, H: gp_Hypr2d) -> gp_Pnt2d: ...
	@overload
	@staticmethod
	def Value(U: float, Prb: gp_Parab2d) -> gp_Pnt2d: ...

# harray1 classes
# harray2 classes
# hsequence classes

elclib_AdjustPeriodic = elclib.AdjustPeriodic
elclib_CircleD1 = elclib.CircleD1
elclib_CircleD1 = elclib.CircleD1
elclib_CircleD2 = elclib.CircleD2
elclib_CircleD2 = elclib.CircleD2
elclib_CircleD3 = elclib.CircleD3
elclib_CircleD3 = elclib.CircleD3
elclib_CircleDN = elclib.CircleDN
elclib_CircleDN = elclib.CircleDN
elclib_CircleParameter = elclib.CircleParameter
elclib_CircleParameter = elclib.CircleParameter
elclib_CircleValue = elclib.CircleValue
elclib_CircleValue = elclib.CircleValue
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D1 = elclib.D1
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D2 = elclib.D2
elclib_D3 = elclib.D3
elclib_D3 = elclib.D3
elclib_D3 = elclib.D3
elclib_D3 = elclib.D3
elclib_D3 = elclib.D3
elclib_D3 = elclib.D3
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_DN = elclib.DN
elclib_EllipseD1 = elclib.EllipseD1
elclib_EllipseD1 = elclib.EllipseD1
elclib_EllipseD2 = elclib.EllipseD2
elclib_EllipseD2 = elclib.EllipseD2
elclib_EllipseD3 = elclib.EllipseD3
elclib_EllipseD3 = elclib.EllipseD3
elclib_EllipseDN = elclib.EllipseDN
elclib_EllipseDN = elclib.EllipseDN
elclib_EllipseParameter = elclib.EllipseParameter
elclib_EllipseParameter = elclib.EllipseParameter
elclib_EllipseValue = elclib.EllipseValue
elclib_EllipseValue = elclib.EllipseValue
elclib_HyperbolaD1 = elclib.HyperbolaD1
elclib_HyperbolaD1 = elclib.HyperbolaD1
elclib_HyperbolaD2 = elclib.HyperbolaD2
elclib_HyperbolaD2 = elclib.HyperbolaD2
elclib_HyperbolaD3 = elclib.HyperbolaD3
elclib_HyperbolaD3 = elclib.HyperbolaD3
elclib_HyperbolaDN = elclib.HyperbolaDN
elclib_HyperbolaDN = elclib.HyperbolaDN
elclib_HyperbolaParameter = elclib.HyperbolaParameter
elclib_HyperbolaParameter = elclib.HyperbolaParameter
elclib_HyperbolaValue = elclib.HyperbolaValue
elclib_HyperbolaValue = elclib.HyperbolaValue
elclib_InPeriod = elclib.InPeriod
elclib_LineD1 = elclib.LineD1
elclib_LineD1 = elclib.LineD1
elclib_LineDN = elclib.LineDN
elclib_LineDN = elclib.LineDN
elclib_LineParameter = elclib.LineParameter
elclib_LineParameter = elclib.LineParameter
elclib_LineValue = elclib.LineValue
elclib_LineValue = elclib.LineValue
elclib_ParabolaD1 = elclib.ParabolaD1
elclib_ParabolaD1 = elclib.ParabolaD1
elclib_ParabolaD2 = elclib.ParabolaD2
elclib_ParabolaD2 = elclib.ParabolaD2
elclib_ParabolaDN = elclib.ParabolaDN
elclib_ParabolaDN = elclib.ParabolaDN
elclib_ParabolaParameter = elclib.ParabolaParameter
elclib_ParabolaParameter = elclib.ParabolaParameter
elclib_ParabolaValue = elclib.ParabolaValue
elclib_ParabolaValue = elclib.ParabolaValue
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_Parameter = elclib.Parameter
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_To3d = elclib.To3d
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value
elclib_Value = elclib.Value



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Storage module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_storage.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Storage
else:
    import _Storage

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Storage.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Storage.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Storage.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Storage.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Storage.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Storage.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Storage.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Storage.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Storage.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Storage.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Storage.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Storage.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Storage.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Storage.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Storage.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Storage.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Storage.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Storage:
_Storage.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Storage.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection

from enum import IntEnum
from OCC.Core.Exception import *

Storage_AddSolve = _Storage.Storage_AddSolve
Storage_WriteSolve = _Storage.Storage_WriteSolve
Storage_ReadSolve = _Storage.Storage_ReadSolve
Storage_VSOk = _Storage.Storage_VSOk
Storage_VSOpenError = _Storage.Storage_VSOpenError
Storage_VSModeError = _Storage.Storage_VSModeError
Storage_VSCloseError = _Storage.Storage_VSCloseError
Storage_VSAlreadyOpen = _Storage.Storage_VSAlreadyOpen
Storage_VSNotOpen = _Storage.Storage_VSNotOpen
Storage_VSSectionNotFound = _Storage.Storage_VSSectionNotFound
Storage_VSWriteError = _Storage.Storage_VSWriteError
Storage_VSFormatError = _Storage.Storage_VSFormatError
Storage_VSUnknownType = _Storage.Storage_VSUnknownType
Storage_VSTypeMismatch = _Storage.Storage_VSTypeMismatch
Storage_VSInternalError = _Storage.Storage_VSInternalError
Storage_VSExtCharParityError = _Storage.Storage_VSExtCharParityError
Storage_VSWrongFileDriver = _Storage.Storage_VSWrongFileDriver
Storage_VSNone = _Storage.Storage_VSNone
Storage_VSRead = _Storage.Storage_VSRead
Storage_VSWrite = _Storage.Storage_VSWrite
Storage_VSReadWrite = _Storage.Storage_VSReadWrite


class Storage_SolveMode(IntEnum):
	Storage_AddSolve = 0
	Storage_WriteSolve = 1
	Storage_ReadSolve = 2
Storage_AddSolve = Storage_SolveMode.Storage_AddSolve
Storage_WriteSolve = Storage_SolveMode.Storage_WriteSolve
Storage_ReadSolve = Storage_SolveMode.Storage_ReadSolve

class Storage_Error(IntEnum):
	Storage_VSOk = 0
	Storage_VSOpenError = 1
	Storage_VSModeError = 2
	Storage_VSCloseError = 3
	Storage_VSAlreadyOpen = 4
	Storage_VSNotOpen = 5
	Storage_VSSectionNotFound = 6
	Storage_VSWriteError = 7
	Storage_VSFormatError = 8
	Storage_VSUnknownType = 9
	Storage_VSTypeMismatch = 10
	Storage_VSInternalError = 11
	Storage_VSExtCharParityError = 12
	Storage_VSWrongFileDriver = 13
Storage_VSOk = Storage_Error.Storage_VSOk
Storage_VSOpenError = Storage_Error.Storage_VSOpenError
Storage_VSModeError = Storage_Error.Storage_VSModeError
Storage_VSCloseError = Storage_Error.Storage_VSCloseError
Storage_VSAlreadyOpen = Storage_Error.Storage_VSAlreadyOpen
Storage_VSNotOpen = Storage_Error.Storage_VSNotOpen
Storage_VSSectionNotFound = Storage_Error.Storage_VSSectionNotFound
Storage_VSWriteError = Storage_Error.Storage_VSWriteError
Storage_VSFormatError = Storage_Error.Storage_VSFormatError
Storage_VSUnknownType = Storage_Error.Storage_VSUnknownType
Storage_VSTypeMismatch = Storage_Error.Storage_VSTypeMismatch
Storage_VSInternalError = Storage_Error.Storage_VSInternalError
Storage_VSExtCharParityError = Storage_Error.Storage_VSExtCharParityError
Storage_VSWrongFileDriver = Storage_Error.Storage_VSWrongFileDriver

class Storage_OpenMode(IntEnum):
	Storage_VSNone = 0
	Storage_VSRead = 1
	Storage_VSWrite = 2
	Storage_VSReadWrite = 3
Storage_VSNone = Storage_OpenMode.Storage_VSNone
Storage_VSRead = Storage_OpenMode.Storage_VSRead
Storage_VSWrite = Storage_OpenMode.Storage_VSWrite
Storage_VSReadWrite = Storage_OpenMode.Storage_VSReadWrite

class Storage_ArrayOfCallBack(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Storage_CallBack > >::iterator":
        return _Storage.Storage_ArrayOfCallBack_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Storage_CallBack > >::iterator":
        return _Storage.Storage_ArrayOfCallBack_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Storage_CallBack > >::const_iterator":
        return _Storage.Storage_ArrayOfCallBack_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Storage_CallBack > >::const_iterator":
        return _Storage.Storage_ArrayOfCallBack_cend(self)

    def __init__(self, *args):
        _Storage.Storage_ArrayOfCallBack_swiginit(self, _Storage.new_Storage_ArrayOfCallBack(*args))

    def Init(self, theValue: "opencascade::handle< Storage_CallBack > const &") -> "void":
        return _Storage.Storage_ArrayOfCallBack_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfCallBack_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfCallBack_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Storage.Storage_ArrayOfCallBack_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfCallBack_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfCallBack_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _Storage.Storage_ArrayOfCallBack_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _Storage.Storage_ArrayOfCallBack_IsAllocated(self)

    def Assign(self, theOther: "Storage_ArrayOfCallBack") -> "NCollection_Array1< opencascade::handle< Storage_CallBack > > &":
        return _Storage.Storage_ArrayOfCallBack_Assign(self, theOther)

    def Move(self, theOther: "Storage_ArrayOfCallBack") -> "NCollection_Array1< opencascade::handle< Storage_CallBack > > &":
        return _Storage.Storage_ArrayOfCallBack_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Storage_CallBack > > &":
        return _Storage.Storage_ArrayOfCallBack_Set(self, *args)

    def First(self) -> "opencascade::handle< Storage_CallBack > const &":
        return _Storage.Storage_ArrayOfCallBack_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Storage_CallBack > &":
        return _Storage.Storage_ArrayOfCallBack_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Storage_CallBack > const &":
        return _Storage.Storage_ArrayOfCallBack_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Storage_CallBack > &":
        return _Storage.Storage_ArrayOfCallBack_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Storage_CallBack > const &":
        return _Storage.Storage_ArrayOfCallBack_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Storage_CallBack > &":
        return _Storage.Storage_ArrayOfCallBack_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Storage_CallBack > &":
        return _Storage.Storage_ArrayOfCallBack___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Storage_CallBack > const &") -> "void":
        return _Storage.Storage_ArrayOfCallBack_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _Storage.Storage_ArrayOfCallBack_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _Storage.delete_Storage_ArrayOfCallBack

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register Storage_ArrayOfCallBack in _Storage:
_Storage.Storage_ArrayOfCallBack_swigregister(Storage_ArrayOfCallBack)

class Storage_ArrayOfSchema(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< opencascade::handle< Storage_Schema > >::iterator":
        return _Storage.Storage_ArrayOfSchema_begin(self)

    def end(self) -> "NCollection_Array1< opencascade::handle< Storage_Schema > >::iterator":
        return _Storage.Storage_ArrayOfSchema_end(self)

    def cbegin(self) -> "NCollection_Array1< opencascade::handle< Storage_Schema > >::const_iterator":
        return _Storage.Storage_ArrayOfSchema_cbegin(self)

    def cend(self) -> "NCollection_Array1< opencascade::handle< Storage_Schema > >::const_iterator":
        return _Storage.Storage_ArrayOfSchema_cend(self)

    def __init__(self, *args):
        _Storage.Storage_ArrayOfSchema_swiginit(self, _Storage.new_Storage_ArrayOfSchema(*args))

    def Init(self, theValue: "opencascade::handle< Storage_Schema > const &") -> "void":
        return _Storage.Storage_ArrayOfSchema_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfSchema_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfSchema_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Storage.Storage_ArrayOfSchema_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfSchema_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Storage.Storage_ArrayOfSchema_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _Storage.Storage_ArrayOfSchema_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _Storage.Storage_ArrayOfSchema_IsAllocated(self)

    def Assign(self, theOther: "Storage_ArrayOfSchema") -> "NCollection_Array1< opencascade::handle< Storage_Schema > > &":
        return _Storage.Storage_ArrayOfSchema_Assign(self, theOther)

    def Move(self, theOther: "Storage_ArrayOfSchema") -> "NCollection_Array1< opencascade::handle< Storage_Schema > > &":
        return _Storage.Storage_ArrayOfSchema_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< opencascade::handle< Storage_Schema > > &":
        return _Storage.Storage_ArrayOfSchema_Set(self, *args)

    def First(self) -> "opencascade::handle< Storage_Schema > const &":
        return _Storage.Storage_ArrayOfSchema_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Storage_Schema > &":
        return _Storage.Storage_ArrayOfSchema_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Storage_Schema > const &":
        return _Storage.Storage_ArrayOfSchema_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Storage_Schema > &":
        return _Storage.Storage_ArrayOfSchema_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Storage_Schema > const &":
        return _Storage.Storage_ArrayOfSchema_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Storage_Schema > &":
        return _Storage.Storage_ArrayOfSchema_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Storage_Schema > &":
        return _Storage.Storage_ArrayOfSchema___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Storage_Schema > const &") -> "void":
        return _Storage.Storage_ArrayOfSchema_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _Storage.Storage_ArrayOfSchema_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _Storage.delete_Storage_ArrayOfSchema

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register Storage_ArrayOfSchema in _Storage:
_Storage.Storage_ArrayOfSchema_swigregister(Storage_ArrayOfSchema)

class Storage_MapOfCallBack(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_TypedCallBack >,TCollection_AsciiString >::iterator":
        return _Storage.Storage_MapOfCallBack_begin(self)

    def end(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_TypedCallBack >,TCollection_AsciiString >::iterator":
        return _Storage.Storage_MapOfCallBack_end(self)

    def cbegin(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_TypedCallBack >,TCollection_AsciiString >::const_iterator":
        return _Storage.Storage_MapOfCallBack_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_TypedCallBack >,TCollection_AsciiString >::const_iterator":
        return _Storage.Storage_MapOfCallBack_cend(self)

    def __init__(self, *args):
        _Storage.Storage_MapOfCallBack_swiginit(self, _Storage.new_Storage_MapOfCallBack(*args))

    def Exchange(self, theOther: "Storage_MapOfCallBack") -> "void":
        return _Storage.Storage_MapOfCallBack_Exchange(self, theOther)

    def Assign(self, theOther: "Storage_MapOfCallBack") -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_TypedCallBack >,TCollection_AsciiString > &":
        return _Storage.Storage_MapOfCallBack_Assign(self, theOther)

    def Set(self, theOther: "Storage_MapOfCallBack") -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_TypedCallBack >,TCollection_AsciiString > &":
        return _Storage.Storage_MapOfCallBack_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _Storage.Storage_MapOfCallBack_ReSize(self, N)

    def Bind(self, theKey: "TCollection_AsciiString const &", theItem: "opencascade::handle< Storage_TypedCallBack > const &") -> "Standard_Boolean":
        return _Storage.Storage_MapOfCallBack_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TCollection_AsciiString const &", theItem: "opencascade::handle< Storage_TypedCallBack > const &") -> "opencascade::handle< Storage_TypedCallBack > *":
        return _Storage.Storage_MapOfCallBack_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TCollection_AsciiString const &") -> "Standard_Boolean":
        return _Storage.Storage_MapOfCallBack_IsBound(self, theKey)

    def UnBind(self, theKey: "TCollection_AsciiString const &") -> "Standard_Boolean":
        return _Storage.Storage_MapOfCallBack_UnBind(self, theKey)

    def Seek(self, theKey: "TCollection_AsciiString const &") -> "opencascade::handle< Storage_TypedCallBack > const *":
        return _Storage.Storage_MapOfCallBack_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _Storage.Storage_MapOfCallBack_Find(self, *args)

    def ChangeSeek(self, theKey: "TCollection_AsciiString const &") -> "opencascade::handle< Storage_TypedCallBack > *":
        return _Storage.Storage_MapOfCallBack_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TCollection_AsciiString const &") -> "opencascade::handle< Storage_TypedCallBack > &":
        return _Storage.Storage_MapOfCallBack_ChangeFind(self, theKey)

    def __call__(self, *args) -> "opencascade::handle< Storage_TypedCallBack > &":
        return _Storage.Storage_MapOfCallBack___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _Storage.Storage_MapOfCallBack_Clear(self, *args)
    __swig_destroy__ = _Storage.delete_Storage_MapOfCallBack

    def Size(self) -> "Standard_Integer":
        return _Storage.Storage_MapOfCallBack_Size(self)

# Register Storage_MapOfCallBack in _Storage:
_Storage.Storage_MapOfCallBack_swigregister(Storage_MapOfCallBack)

class Storage_MapOfPers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_Root >,TCollection_AsciiString >::iterator":
        return _Storage.Storage_MapOfPers_begin(self)

    def end(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_Root >,TCollection_AsciiString >::iterator":
        return _Storage.Storage_MapOfPers_end(self)

    def cbegin(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_Root >,TCollection_AsciiString >::const_iterator":
        return _Storage.Storage_MapOfPers_cbegin(self)

    def cend(self) -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_Root >,TCollection_AsciiString >::const_iterator":
        return _Storage.Storage_MapOfPers_cend(self)

    def __init__(self, *args):
        _Storage.Storage_MapOfPers_swiginit(self, _Storage.new_Storage_MapOfPers(*args))

    def Exchange(self, theOther: "Storage_MapOfPers") -> "void":
        return _Storage.Storage_MapOfPers_Exchange(self, theOther)

    def Assign(self, theOther: "Storage_MapOfPers") -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_Root >,TCollection_AsciiString > &":
        return _Storage.Storage_MapOfPers_Assign(self, theOther)

    def Set(self, theOther: "Storage_MapOfPers") -> "NCollection_DataMap< TCollection_AsciiString,opencascade::handle< Storage_Root >,TCollection_AsciiString > &":
        return _Storage.Storage_MapOfPers_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _Storage.Storage_MapOfPers_ReSize(self, N)

    def Bind(self, theKey: "TCollection_AsciiString const &", theItem: "opencascade::handle< Storage_Root > const &") -> "Standard_Boolean":
        return _Storage.Storage_MapOfPers_Bind(self, theKey, theItem)

    def Bound(self, theKey: "TCollection_AsciiString const &", theItem: "opencascade::handle< Storage_Root > const &") -> "opencascade::handle< Storage_Root > *":
        return _Storage.Storage_MapOfPers_Bound(self, theKey, theItem)

    def IsBound(self, theKey: "TCollection_AsciiString const &") -> "Standard_Boolean":
        return _Storage.Storage_MapOfPers_IsBound(self, theKey)

    def UnBind(self, theKey: "TCollection_AsciiString const &") -> "Standard_Boolean":
        return _Storage.Storage_MapOfPers_UnBind(self, theKey)

    def Seek(self, theKey: "TCollection_AsciiString const &") -> "opencascade::handle< Storage_Root > const *":
        return _Storage.Storage_MapOfPers_Seek(self, theKey)

    def Find(self, *args) -> "Standard_Boolean":
        return _Storage.Storage_MapOfPers_Find(self, *args)

    def ChangeSeek(self, theKey: "TCollection_AsciiString const &") -> "opencascade::handle< Storage_Root > *":
        return _Storage.Storage_MapOfPers_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey: "TCollection_AsciiString const &") -> "opencascade::handle< Storage_Root > &":
        return _Storage.Storage_MapOfPers_ChangeFind(self, theKey)

    def __call__(self, *args) -> "opencascade::handle< Storage_Root > &":
        return _Storage.Storage_MapOfPers___call__(self, *args)

    def Clear(self, *args) -> "void":
        return _Storage.Storage_MapOfPers_Clear(self, *args)
    __swig_destroy__ = _Storage.delete_Storage_MapOfPers

    def Size(self) -> "Standard_Integer":
        return _Storage.Storage_MapOfPers_Size(self)

# Register Storage_MapOfPers in _Storage:
_Storage.Storage_MapOfPers_swigregister(Storage_MapOfPers)

class Storage_PType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_IndexedDataMap< TCollection_AsciiString,int,TCollection_AsciiString >::iterator":
        return _Storage.Storage_PType_begin(self)

    def end(self) -> "NCollection_IndexedDataMap< TCollection_AsciiString,int,TCollection_AsciiString >::iterator":
        return _Storage.Storage_PType_end(self)

    def cbegin(self) -> "NCollection_IndexedDataMap< TCollection_AsciiString,int,TCollection_AsciiString >::const_iterator":
        return _Storage.Storage_PType_cbegin(self)

    def cend(self) -> "NCollection_IndexedDataMap< TCollection_AsciiString,int,TCollection_AsciiString >::const_iterator":
        return _Storage.Storage_PType_cend(self)

    def __init__(self, *args):
        _Storage.Storage_PType_swiginit(self, _Storage.new_Storage_PType(*args))

    def Exchange(self, theOther: "Storage_PType") -> "void":
        return _Storage.Storage_PType_Exchange(self, theOther)

    def Assign(self, theOther: "Storage_PType") -> "NCollection_IndexedDataMap< TCollection_AsciiString,Standard_Integer,TCollection_AsciiString > &":
        return _Storage.Storage_PType_Assign(self, theOther)

    def Set(self, theOther: "Storage_PType") -> "NCollection_IndexedDataMap< TCollection_AsciiString,Standard_Integer,TCollection_AsciiString > &":
        return _Storage.Storage_PType_Set(self, theOther)

    def ReSize(self, N: "Standard_Integer const") -> "void":
        return _Storage.Storage_PType_ReSize(self, N)

    def Add(self, theKey1: "TCollection_AsciiString const &", theItem: "int const &") -> "Standard_Integer":
        return _Storage.Storage_PType_Add(self, theKey1, theItem)

    def Contains(self, theKey1: "TCollection_AsciiString const &") -> "Standard_Boolean":
        return _Storage.Storage_PType_Contains(self, theKey1)

    def Substitute(self, theIndex: "Standard_Integer const", theKey1: "TCollection_AsciiString const &", theItem: "int const &") -> "void":
        return _Storage.Storage_PType_Substitute(self, theIndex, theKey1, theItem)

    def Swap(self, theIndex1: "Standard_Integer const", theIndex2: "Standard_Integer const") -> "void":
        return _Storage.Storage_PType_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self) -> "void":
        return _Storage.Storage_PType_RemoveLast(self)

    def RemoveFromIndex(self, theIndex: "Standard_Integer const") -> "void":
        return _Storage.Storage_PType_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1: "TCollection_AsciiString const &") -> "void":
        return _Storage.Storage_PType_RemoveKey(self, theKey1)

    def FindKey(self, theIndex: "Standard_Integer const") -> "TCollection_AsciiString const &":
        return _Storage.Storage_PType_FindKey(self, theIndex)

    def FindFromIndex(self, theIndex: "Standard_Integer const") -> "int const &":
        return _Storage.Storage_PType_FindFromIndex(self, theIndex)

    def ChangeFromIndex(self, theIndex: "Standard_Integer const") -> "int &":
        return _Storage.Storage_PType_ChangeFromIndex(self, theIndex)

    def __call__(self, *args) -> "int &":
        return _Storage.Storage_PType___call__(self, *args)

    def FindIndex(self, theKey1: "TCollection_AsciiString const &") -> "Standard_Integer":
        return _Storage.Storage_PType_FindIndex(self, theKey1)

    def ChangeFromKey(self, theKey1: "TCollection_AsciiString const &") -> "int &":
        return _Storage.Storage_PType_ChangeFromKey(self, theKey1)

    def Seek(self, theKey1: "TCollection_AsciiString const &") -> "int const *":
        return _Storage.Storage_PType_Seek(self, theKey1)

    def ChangeSeek(self, theKey1: "TCollection_AsciiString const &") -> "int *":
        return _Storage.Storage_PType_ChangeSeek(self, theKey1)

    def FindFromKey(self, *args) -> "Standard_Boolean":
        return _Storage.Storage_PType_FindFromKey(self, *args)

    def Clear(self, *args) -> "void":
        return _Storage.Storage_PType_Clear(self, *args)
    __swig_destroy__ = _Storage.delete_Storage_PType

    def Size(self) -> "Standard_Integer":
        return _Storage.Storage_PType_Size(self)

# Register Storage_PType in _Storage:
_Storage.Storage_PType_swigregister(Storage_PType)

class Storage_SeqOfRoot(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Sequence< opencascade::handle< Storage_Root > >::iterator":
        return _Storage.Storage_SeqOfRoot_begin(self)

    def end(self) -> "NCollection_Sequence< opencascade::handle< Storage_Root > >::iterator":
        return _Storage.Storage_SeqOfRoot_end(self)

    def cbegin(self) -> "NCollection_Sequence< opencascade::handle< Storage_Root > >::const_iterator":
        return _Storage.Storage_SeqOfRoot_cbegin(self)

    def cend(self) -> "NCollection_Sequence< opencascade::handle< Storage_Root > >::const_iterator":
        return _Storage.Storage_SeqOfRoot_cend(self)

    def __init__(self, *args):
        _Storage.Storage_SeqOfRoot_swiginit(self, _Storage.new_Storage_SeqOfRoot(*args))

    def Size(self) -> "Standard_Integer":
        return _Storage.Storage_SeqOfRoot_Size(self)

    def Length(self) -> "Standard_Integer":
        return _Storage.Storage_SeqOfRoot_Length(self)

    def Lower(self) -> "Standard_Integer":
        return _Storage.Storage_SeqOfRoot_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _Storage.Storage_SeqOfRoot_Upper(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _Storage.Storage_SeqOfRoot_IsEmpty(self)

    def Reverse(self) -> "void":
        return _Storage.Storage_SeqOfRoot_Reverse(self)

    def Exchange(self, I: "Standard_Integer const", J: "Standard_Integer const") -> "void":
        return _Storage.Storage_SeqOfRoot_Exchange(self, I, J)

    @staticmethod
    def delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
        return _Storage.Storage_SeqOfRoot_delNode(theNode, theAl)

    def Clear(self, theAllocator: "opencascade::handle< NCollection_BaseAllocator > const &"=0) -> "void":
        return _Storage.Storage_SeqOfRoot_Clear(self, theAllocator)

    def Assign(self, theOther: "Storage_SeqOfRoot") -> "NCollection_Sequence< opencascade::handle< Storage_Root > > &":
        return _Storage.Storage_SeqOfRoot_Assign(self, theOther)

    def Set(self, theOther: "Storage_SeqOfRoot") -> "NCollection_Sequence< opencascade::handle< Storage_Root > > &":
        return _Storage.Storage_SeqOfRoot_Set(self, theOther)

    def Remove(self, *args) -> "void":
        return _Storage.Storage_SeqOfRoot_Remove(self, *args)

    def Append(self, *args) -> "void":
        return _Storage.Storage_SeqOfRoot_Append(self, *args)

    def Prepend(self, *args) -> "void":
        return _Storage.Storage_SeqOfRoot_Prepend(self, *args)

    def InsertBefore(self, *args) -> "void":
        return _Storage.Storage_SeqOfRoot_InsertBefore(self, *args)

    def InsertAfter(self, *args) -> "void":
        return _Storage.Storage_SeqOfRoot_InsertAfter(self, *args)

    def Split(self, theIndex: "Standard_Integer const", theSeq: "Storage_SeqOfRoot") -> "void":
        return _Storage.Storage_SeqOfRoot_Split(self, theIndex, theSeq)

    def First(self) -> "opencascade::handle< Storage_Root > const &":
        return _Storage.Storage_SeqOfRoot_First(self)

    def ChangeFirst(self) -> "opencascade::handle< Storage_Root > &":
        return _Storage.Storage_SeqOfRoot_ChangeFirst(self)

    def Last(self) -> "opencascade::handle< Storage_Root > const &":
        return _Storage.Storage_SeqOfRoot_Last(self)

    def ChangeLast(self) -> "opencascade::handle< Storage_Root > &":
        return _Storage.Storage_SeqOfRoot_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Storage_Root > const &":
        return _Storage.Storage_SeqOfRoot_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "opencascade::handle< Storage_Root > &":
        return _Storage.Storage_SeqOfRoot_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "opencascade::handle< Storage_Root > &":
        return _Storage.Storage_SeqOfRoot___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "opencascade::handle< Storage_Root > const &") -> "void":
        return _Storage.Storage_SeqOfRoot_SetValue(self, theIndex, theItem)
    __swig_destroy__ = _Storage.delete_Storage_SeqOfRoot

    def __len__(self):
        return self.Size()


# Register Storage_SeqOfRoot in _Storage:
_Storage.Storage_SeqOfRoot_swigregister(Storage_SeqOfRoot)

def Storage_SeqOfRoot_delNode(theNode: "NCollection_SeqNode *", theAl: "opencascade::handle< NCollection_BaseAllocator > &") -> "void":
    return _Storage.Storage_SeqOfRoot_delNode(theNode, theAl)


@classnotwrapped
class Storage_Bucket:
	pass

@classnotwrapped
class Storage_BucketOfPersistent:
	pass

@classnotwrapped
class Storage_BucketIterator:
	pass

@classnotwrapped
class Storage_RootData:
	pass

@classnotwrapped
class Storage_TypeData:
	pass

@classnotwrapped
class Storage_Root:
	pass

@classnotwrapped
class Storage_Schema:
	pass

@classnotwrapped
class Storage_DefaultCallBack:
	pass

@classnotwrapped
class Storage_TypedCallBack:
	pass

@classnotwrapped
class Storage_CallBack:
	pass

@classnotwrapped
class Storage_HeaderData:
	pass

@classnotwrapped
class Storage_BaseDriver:
	pass

@classnotwrapped
class Storage_InternalData:
	pass

@classnotwrapped
class Storage_Data:
	pass

@classnotwrapped
class Storage:
	pass


class Storage_HArrayOfSchema(Storage_ArrayOfSchema, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _Storage.Storage_HArrayOfSchema_swiginit(self, _Storage.new_Storage_HArrayOfSchema(*args))

    def Array1(self) -> "Storage_ArrayOfSchema const &":
        return _Storage.Storage_HArrayOfSchema_Array1(self)

    def ChangeArray1(self) -> "Storage_ArrayOfSchema &":
        return _Storage.Storage_HArrayOfSchema_ChangeArray1(self)
    __swig_destroy__ = _Storage.delete_Storage_HArrayOfSchema

# Register Storage_HArrayOfSchema in _Storage:
_Storage.Storage_HArrayOfSchema_swigregister(Storage_HArrayOfSchema)

class Storage_HPArray(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _Storage.Storage_HPArray_swiginit(self, _Storage.new_Storage_HPArray(*args))

    def Array1(self) -> "Storage_PArray const &":
        return _Storage.Storage_HPArray_Array1(self)

    def ChangeArray1(self) -> "Storage_PArray &":
        return _Storage.Storage_HPArray_ChangeArray1(self)
    __swig_destroy__ = _Storage.delete_Storage_HPArray

# Register Storage_HPArray in _Storage:
_Storage.Storage_HPArray_swigregister(Storage_HPArray)

class Storage_HArrayOfCallBack(Storage_ArrayOfCallBack, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _Storage.Storage_HArrayOfCallBack_swiginit(self, _Storage.new_Storage_HArrayOfCallBack(*args))

    def Array1(self) -> "Storage_ArrayOfCallBack const &":
        return _Storage.Storage_HArrayOfCallBack_Array1(self)

    def ChangeArray1(self) -> "Storage_ArrayOfCallBack &":
        return _Storage.Storage_HArrayOfCallBack_ChangeArray1(self)
    __swig_destroy__ = _Storage.delete_Storage_HArrayOfCallBack

# Register Storage_HArrayOfCallBack in _Storage:
_Storage.Storage_HArrayOfCallBack_swigregister(Storage_HArrayOfCallBack)

class Storage_HSeqOfRoot(Storage_SeqOfRoot, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _Storage.Storage_HSeqOfRoot_swiginit(self, _Storage.new_Storage_HSeqOfRoot(*args))

    def Sequence(self) -> "Storage_SeqOfRoot const &":
        return _Storage.Storage_HSeqOfRoot_Sequence(self)

    def Append(self, *args) -> "void":
        return _Storage.Storage_HSeqOfRoot_Append(self, *args)

    def ChangeSequence(self) -> "Storage_SeqOfRoot &":
        return _Storage.Storage_HSeqOfRoot_ChangeSequence(self)
    __swig_destroy__ = _Storage.delete_Storage_HSeqOfRoot

# Register Storage_HSeqOfRoot in _Storage:
_Storage.Storage_HSeqOfRoot_swigregister(Storage_HSeqOfRoot)





